import React, { useState, useEffect } from 'react';
import { useNavigate } from 'react-router-dom';
import { useDispatch } from 'react-redux';
import { showNotification } from '../../store/notification.slice';
import { get } from '../../services/api';
import SvgIcon from '../../components/SvgIcon';

export default function NewChat() {
    const navigate = useNavigate();
    const dispatch = useDispatch();
    const [knowledgeBases, setKnowledgeBases] = useState([]);
    const [loading, setLoading] = useState(true);

    // 获取知识库列表
    useEffect(() => {
        const fetchKnowledgeBases = async () => {
            try {
                setLoading(true);
                const response = await get('/knowledge-bases/');

                // 过滤出有 can_read 权限的知识库
                const readableKnowledgeBases = response.data.items.filter(
                    (kb) => kb.permissions && kb.permissions.can_read === true
                );

                setKnowledgeBases(readableKnowledgeBases);
            } catch (error) {
                console.error('获取知识库列表失败:', error);
                dispatch(
                    showNotification({
                        message: '获取知识库列表失败，请稍后重试',
                        type: 'danger',
                    })
                );
            } finally {
                setLoading(false);
            }
        };

        fetchKnowledgeBases();
    }, [dispatch]);

    const handleSelectKnowledgeBase = (knowledgeBaseId) => {
        // 创建新聊天并导航到聊天页面
        navigate(`/chat/${knowledgeBaseId}`);
    };

    return (
        <div className='new-chat container py-4'>
            <div className='text-center mb-5'>
                <h2 className='mb-4'>选择知识库开始聊天</h2>
            </div>

            {loading ? (
                <div className='d-flex justify-content-center my-5'>
                    <div className='spinner-border' role='status'>
                        <span className='visually-hidden'>加载中...</span>
                    </div>
                </div>
            ) : knowledgeBases.length === 0 ? (
                <div className='text-center my-5'>
                    <p className='text-muted'>没有可用的知识库，请联系管理员获取权限</p>
                </div>
            ) : (
                <div className='row row-cols-1 row-cols-md-2 row-cols-lg-3 g-4 justify-content-center'>
                    {knowledgeBases.map((kb) => (
                        <div key={kb.id} className='col'>
                            <div
                                className='card h-100 bg-light border-0 cursor-pointer'
                                onClick={() => handleSelectKnowledgeBase(kb.id)}
                                style={{ cursor: 'pointer' }}
                            >
                                <div className='card-body py-4'>
                                    <p className='card-title h5'>{kb.name}</p>
                                    <p className='card-text text-muted'>{kb.description}</p>
                                    <div className='d-flex justify-content-between align-items-center mt-3'>
                                        <small className='text-muted'>文档数: {kb.document_count || 0}</small>
                                    </div>
                                </div>
                            </div>
                        </div>
                    ))}
                </div>
            )}
        </div>
    );
}
