import React, { useState, useEffect } from 'react';
import { useNavigate } from 'react-router-dom';
import { useDispatch, useSelector } from 'react-redux';
import { showNotification } from '../../store/notification.slice';
import {
    fetchKnowledgeBases,
    searchKnowledgeBases,
    createKnowledgeBase,
} from '../../store/knowledgeBase/knowledgeBase.thunks';
import { resetSearchState } from '../../store/knowledgeBase/knowledgeBase.slice';
import SvgIcon from '../../components/SvgIcon';
import { requestKnowledgeBaseAccess } from '../../services/permissionService';
import AccessRequestModal from '../../components/AccessRequestModal';
import CreateKnowledgeBaseModal from '../../components/CreateKnowledgeBaseModal';
import Pagination from '../../components/Pagination';
import SearchBar from '../../components/SearchBar';

// 导入拆分的组件
import KnowledgeBaseList from './components/KnowledgeBaseList';

export default function KnowledgeBase() {
    const dispatch = useDispatch();
    const navigate = useNavigate();
    const [showCreateModal, setShowCreateModal] = useState(false);
    const [showAccessRequestModal, setShowAccessRequestModal] = useState(false);
    const [formErrors, setFormErrors] = useState({});
    const [accessRequestKnowledgeBase, setAccessRequestKnowledgeBase] = useState({
        id: '',
        title: '',
    });
    const [isSubmittingRequest, setIsSubmittingRequest] = useState(false);

    // 获取当前用户信息
    const currentUser = useSelector((state) => state.auth.user);

    const [newKnowledgeBase, setNewKnowledgeBase] = useState({
        name: '',
        desc: '',
        type: 'private', // 默认为私有知识库
        department: currentUser?.department || '',
        group: currentUser?.group || '',
    });

    // Search state
    const [searchKeyword, setSearchKeyword] = useState('');
    const [isSearching, setIsSearching] = useState(false);

    // Pagination state
    const [pagination, setPagination] = useState({
        page: 1,
        page_size: 10,
    });

    // Get knowledge bases from Redux store
    const { data, status, error } = useSelector((state) => state.knowledgeBase.list);
    const {
        data: searchData,
        status: searchStatus,
        error: searchError,
        keyword: storeKeyword,
    } = useSelector((state) => state.knowledgeBase.search);
    const { status: operationStatus, error: operationError } = useSelector((state) => state.knowledgeBase.operations);

    // Determine which data to display based on search state
    const displayData = isSearching ? searchData?.items : data?.items;
    const displayTotal = isSearching ? searchData?.total : data?.total;
    const displayStatus = isSearching ? searchStatus : status;
    const displayError = isSearching ? searchError : error;

    // Fetch knowledge bases when component mounts or pagination changes
    useEffect(() => {
        if (!isSearching) {
            dispatch(fetchKnowledgeBases(pagination));
        } else if (searchKeyword.trim()) {
            dispatch(
                searchKnowledgeBases({
                    keyword: searchKeyword,
                    page: pagination.page,
                    page_size: pagination.page_size,
                })
            );
        }
    }, [dispatch, pagination.page, pagination.page_size, isSearching, searchKeyword]);

    // Handle search input change
    const handleSearchInputChange = (e) => {
        setSearchKeyword(e.target.value);
    };

    // Handle search submit
    const handleSearch = (e) => {
        e.preventDefault();

        if (searchKeyword.trim()) {
            setIsSearching(true);
            setPagination((prev) => ({ ...prev, page: 1 })); // Reset to first page
            dispatch(
                searchKnowledgeBases({
                    keyword: searchKeyword,
                    page: 1,
                    page_size: pagination.page_size,
                })
            );
        } else {
            // If search is empty, reset to normal list view
            handleClearSearch();
        }
    };

    // Handle clear search
    const handleClearSearch = () => {
        setSearchKeyword('');
        setIsSearching(false);
        setPagination((prev) => ({ ...prev, page: 1 })); // Reset to first page
        dispatch(resetSearchState());
    };

    // Show loading state while fetching data
    const isLoading = displayStatus === 'loading';

    // Show error notification if fetch fails
    useEffect(() => {
        if (displayStatus === 'failed' && displayError) {
            dispatch(
                showNotification({
                    message: `获取知识库列表失败: ${displayError.message || displayError}`,
                    type: 'danger',
                })
            );
        }
    }, [displayStatus, displayError, dispatch]);

    // Show notification for operation status
    useEffect(() => {
        if (operationStatus === 'succeeded') {
            dispatch(
                showNotification({
                    message: '操作成功',
                    type: 'success',
                })
            );
            // Refresh the list after successful operation
            if (isSearching && searchKeyword.trim()) {
                dispatch(
                    searchKnowledgeBases({
                        keyword: searchKeyword,
                        page: pagination.page,
                        page_size: pagination.page_size,
                    })
                );
            } else {
                dispatch(fetchKnowledgeBases(pagination));
            }
        } else if (operationStatus === 'failed' && operationError) {
            dispatch(
                showNotification({
                    message: `操作失败: ${operationError.message || operationError}`,
                    type: 'danger',
                })
            );
        }
    }, [operationStatus, operationError, dispatch, pagination, isSearching, searchKeyword]);

    // Handle pagination change
    const handlePageChange = (newPage) => {
        setPagination((prev) => ({
            ...prev,
            page: newPage,
        }));
    };

    // Handle page size change
    const handlePageSizeChange = (newPageSize) => {
        setPagination({
            page: 1, // Reset to first page when changing page size
            page_size: newPageSize,
        });
    };

    const handleInputChange = (e) => {
        const { name, value } = e.target;
        // 不允许修改部门和组别字段
        if (name === 'department' || name === 'group') {
            return;
        }

        setNewKnowledgeBase((prev) => ({
            ...prev,
            [name]: value,
        }));

        // Clear error when user types
        if (formErrors[name]) {
            setFormErrors((prev) => ({
                ...prev,
                [name]: '',
            }));
        }
    };

    const validateCreateForm = () => {
        const errors = {};

        if (!newKnowledgeBase.name.trim()) {
            errors.name = '请输入知识库名称';
        }

        if (!newKnowledgeBase.desc.trim()) {
            errors.desc = '请输入知识库描述';
        }

        if (!newKnowledgeBase.type) {
            errors.type = '请选择知识库类型';
        }

        setFormErrors(errors);
        return Object.keys(errors).length === 0;
    };

    const handleCreateKnowledgeBase = () => {
        // Validate form
        if (!validateCreateForm()) {
            return;
        }

        // Dispatch create knowledge base action
        dispatch(
            createKnowledgeBase({
                name: newKnowledgeBase.name,
                desc: newKnowledgeBase.desc,
                description: newKnowledgeBase.desc,
                type: newKnowledgeBase.type,
                department: newKnowledgeBase.department,
                group: newKnowledgeBase.group,
            })
        );

        // Reset form and close modal
        setNewKnowledgeBase({ name: '', desc: '', type: 'private', department: '', group: '' });
        setFormErrors({});
        setShowCreateModal(false);
    };

    // Handle card click to navigate to knowledge base detail
    const handleCardClick = (id, permissions) => {
        // 检查用户是否有读取权限
        if (!permissions || permissions.can_read === false) {
            dispatch(
                showNotification({
                    message: '您没有访问此知识库的权限，请先申请权限',
                    type: 'warning',
                })
            );
            return;
        }

        // 有权限则跳转到详情页
        navigate(`/knowledge-base/${id}/datasets`);
    };

    const handleRequestAccess = (id, title) => {
        setAccessRequestKnowledgeBase({
            id,
            title,
        });
        setShowAccessRequestModal(true);
    };

    const handleSubmitAccessRequest = async (requestData) => {
        setIsSubmittingRequest(true);

        try {
            // 使用权限服务发送请求
            await requestKnowledgeBaseAccess(requestData);

            dispatch(
                showNotification({
                    message: '权限申请已提交',
                    type: 'success',
                })
            );

            // Close modal
            setShowAccessRequestModal(false);
        } catch (error) {
            dispatch(
                showNotification({
                    message: `权限申请失败: ${error.response?.data?.message || '请稍后重试'}`,
                    type: 'danger',
                })
            );
        } finally {
            setIsSubmittingRequest(false);
        }
    };

    const handleDelete = (e, id) => {
        e.preventDefault();
        e.stopPropagation();
        console.log(id);
    };

    // Calculate total pages
    const totalPages = Math.ceil(displayTotal / pagination.page_size);

    // 打开创建知识库弹窗
    const handleOpenCreateModal = () => {
        // 确保部门和组别字段使用当前用户的信息
        setNewKnowledgeBase((prev) => ({
            ...prev,
            department: currentUser?.department || '',
            group: currentUser?.group || '',
        }));
        setShowCreateModal(true);
    };

    return (
        <div className='knowledge-base container my-4'>
            <div className='d-flex justify-content-between align-items-center mb-3'>
                <SearchBar
                    searchKeyword={searchKeyword}
                    isSearching={isSearching}
                    onSearchChange={handleSearchInputChange}
                    onSearch={handleSearch}
                    onClearSearch={handleClearSearch}
                    placeholder='搜索知识库...'
                />
                <button className='btn btn-dark d-flex align-items-center gap-1' onClick={handleOpenCreateModal}>
                    <SvgIcon className={'plus'} />
                    新建知识库
                </button>
            </div>

            {isSearching && (
                <div className='alert alert-info'>
                    搜索结果: "{storeKeyword}" - 找到 {displayTotal} 个知识库
                </div>
            )}

            {isLoading ? (
                <div className='d-flex justify-content-center my-5'>
                    <div className='spinner-border' role='status'>
                        <span className='visually-hidden'>加载中...</span>
                    </div>
                </div>
            ) : (
                <>
                    <KnowledgeBaseList
                        knowledgeBases={displayData}
                        isSearching={isSearching}
                        onCardClick={handleCardClick}
                        onRequestAccess={handleRequestAccess}
                        onDelete={handleDelete}
                    />

                    {/* Pagination */}
                    {totalPages > 1 && (
                        <Pagination
                            currentPage={pagination.page}
                            totalPages={totalPages}
                            pageSize={pagination.page_size}
                            onPageChange={handlePageChange}
                            onPageSizeChange={handlePageSizeChange}
                        />
                    )}
                </>
            )}

            {/* 新建知识库弹窗 */}
            <CreateKnowledgeBaseModal
                show={showCreateModal}
                formData={newKnowledgeBase}
                formErrors={formErrors}
                isSubmitting={operationStatus === 'loading'}
                onClose={() => setShowCreateModal(false)}
                onChange={handleInputChange}
                onSubmit={handleCreateKnowledgeBase}
            />

            {/* 申请权限弹窗 */}
            <AccessRequestModal
                show={showAccessRequestModal}
                knowledgeBaseId={accessRequestKnowledgeBase.id}
                knowledgeBaseTitle={accessRequestKnowledgeBase.title}
                onClose={() => setShowAccessRequestModal(false)}
                onSubmit={handleSubmitAccessRequest}
                isSubmitting={isSubmittingRequest}
            />
        </div>
    );
}
