import React, { useState, useEffect } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { showNotification } from '../../../store/notification.slice';
import {
    fetchPermissionsThunk,
    approvePermissionThunk,
    rejectPermissionThunk,
} from '../../../store/permissions/permissions.thunks';
import { resetApproveRejectStatus } from '../../../store/permissions/permissions.slice';
import './PendingRequests.css'; // 引入外部CSS文件
import SvgIcon from '../../../components/SvgIcon';

// 模拟数据
const mockPendingRequests = [
    {
        id: 1,
        applicant: {
            name: '王五',
            department: '达人组',
        },
        knowledge_base: {
            name: '达人直播数据报告',
        },
        permissions: {
            can_read: true,
            can_edit: true,
            can_delete: false,
        },
        reason: '需要查看和编辑直播数据报告',
        created_at: '2024-01-07T10:30:00Z',
        expires_at: null,
    },
    {
        id: 2,
        applicant: {
            name: '赵六',
            department: '直播组',
        },
        knowledge_base: {
            name: '人力资源政策文件',
        },
        permissions: {
            can_read: true,
            can_edit: false,
            can_delete: false,
        },
        reason: '需要了解最新的人力资源政策',
        created_at: '2024-01-06T14:20:00Z',
        expires_at: '2025-01-06T14:20:00Z',
    },
    {
        id: 3,
        applicant: {
            name: '钱七',
            department: '市场部',
        },
        knowledge_base: {
            name: '市场分析报告',
        },
        permissions: {
            can_read: true,
            can_edit: false,
            can_delete: false,
        },
        reason: '需要了解市场趋势',
        created_at: '2024-01-05T09:15:00Z',
        expires_at: '2024-07-05T09:15:00Z',
    },
    {
        id: 4,
        applicant: {
            name: '孙八',
            department: '技术部',
        },
        knowledge_base: {
            name: '技术架构文档',
        },
        permissions: {
            can_read: true,
            can_edit: true,
            can_delete: true,
        },
        reason: '需要进行技术架构更新',
        created_at: '2024-01-04T16:45:00Z',
        expires_at: null,
    },
    {
        id: 5,
        applicant: {
            name: '周九',
            department: '产品部',
        },
        knowledge_base: {
            name: '产品规划文档',
        },
        permissions: {
            can_read: true,
            can_edit: true,
            can_delete: false,
        },
        reason: '需要参与产品规划讨论',
        created_at: '2024-01-03T11:30:00Z',
        expires_at: '2024-12-31T23:59:59Z',
    },
    {
        id: 6,
        applicant: {
            name: '吴十',
            department: '设计部',
        },
        knowledge_base: {
            name: '设计规范文档',
        },
        permissions: {
            can_read: true,
            can_edit: false,
            can_delete: false,
        },
        reason: '需要参考设计规范',
        created_at: '2024-01-02T14:20:00Z',
        expires_at: '2024-06-30T23:59:59Z',
    },
    {
        id: 7,
        applicant: {
            name: '郑十一',
            department: '财务部',
        },
        knowledge_base: {
            name: '财务报表',
        },
        permissions: {
            can_read: true,
            can_edit: false,
            can_delete: false,
        },
        reason: '需要查看财务数据',
        created_at: '2024-01-01T09:00:00Z',
        expires_at: null,
    },
];

// 每页显示的申请数量
const PAGE_SIZE = 5;

export default function PendingRequests() {
    const dispatch = useDispatch();
    const [responseMessage, setResponseMessage] = useState('');
    const [showResponseInput, setShowResponseInput] = useState(false);
    const [currentRequestId, setCurrentRequestId] = useState(null);
    const [isApproving, setIsApproving] = useState(false);
    const [selectedRequest, setSelectedRequest] = useState(null);
    const [showSlideOver, setShowSlideOver] = useState(false);

    // 使用本地状态管理待处理申请列表
    const [pendingRequests, setPendingRequests] = useState([]);
    const [fetchStatus, setFetchStatus] = useState('idle');
    const [fetchError, setFetchError] = useState(null);

    // 分页状态
    const [currentPage, setCurrentPage] = useState(1);
    const [totalPages, setTotalPages] = useState(1);

    // 从Redux store获取批准/拒绝操作的状态
    const {
        status: approveRejectStatus,
        error: approveRejectError,
        currentId: processingId,
    } = useSelector((state) => state.permissions.approveReject);

    // 获取待处理申请列表
    useEffect(() => {
        const fetchData = async () => {
            try {
                setFetchStatus('loading');
                // 尝试从API获取数据
                const result = await dispatch(fetchPermissionsThunk());

                // 检查API返回的数据
                if (result && result.payload && result.payload.length > 0) {
                    // 使用API返回的数据
                    setPendingRequests(result.payload);
                    setTotalPages(Math.ceil(result.payload.length / PAGE_SIZE));
                    console.log('使用API返回的待处理申请数据');
                } else {
                    // API返回的数据为空，使用模拟数据
                    console.log('API返回的待处理申请数据为空，使用模拟数据');
                    setPendingRequests(mockPendingRequests);
                    setTotalPages(Math.ceil(mockPendingRequests.length / PAGE_SIZE));
                }
                setFetchStatus('succeeded');
            } catch (error) {
                console.error('获取待处理申请失败:', error);
                setFetchError('获取待处理申请失败');
                setFetchStatus('failed');

                // API请求失败，使用模拟数据作为后备
                console.log('API请求失败，使用模拟数据作为后备');
                setPendingRequests(mockPendingRequests);
                setTotalPages(Math.ceil(mockPendingRequests.length / PAGE_SIZE));
            }
        };

        fetchData();
    }, [dispatch]);

    // 监听批准/拒绝操作的状态变化
    useEffect(() => {
        if (approveRejectStatus === 'succeeded') {
            dispatch(
                showNotification({
                    message: isApproving ? '已批准申请' : '已拒绝申请',
                    type: 'success',
                })
            );
            setShowResponseInput(false);
            setCurrentRequestId(null);
            setResponseMessage('');
            setShowSlideOver(false);
            setSelectedRequest(null);

            // 从列表中移除已处理的申请
            const updatedRequests = pendingRequests.filter((req) => req.id !== currentRequestId);
            setPendingRequests(updatedRequests);

            // 更新总页数
            setTotalPages(Math.ceil(updatedRequests.length / PAGE_SIZE));

            // 如果当前页没有数据了，且不是第一页，则回到上一页
            if (getCurrentPageData().length === 1 && currentPage > 1) {
                setCurrentPage(currentPage - 1);
            }

            // 重置状态
            dispatch(resetApproveRejectStatus());
        } else if (approveRejectStatus === 'failed') {
            dispatch(
                showNotification({
                    message: approveRejectError || '处理申请失败',
                    type: 'danger',
                })
            );
            // 重置状态
            dispatch(resetApproveRejectStatus());
        }
    }, [
        approveRejectStatus,
        approveRejectError,
        dispatch,
        isApproving,
        currentRequestId,
        pendingRequests,
        currentPage,
    ]);

    // 打开回复输入框
    const handleOpenResponseInput = (requestId, approving) => {
        setCurrentRequestId(requestId);
        setIsApproving(approving);
        setShowResponseInput(true);
    };

    // 关闭回复输入框
    const handleCloseResponseInput = () => {
        setShowResponseInput(false);
        setCurrentRequestId(null);
        setResponseMessage('');
    };

    // 处理申请（批准或拒绝）
    const handleProcessRequest = () => {
        if (!currentRequestId) return;

        const params = {
            id: currentRequestId,
            responseMessage,
        };

        if (isApproving) {
            dispatch(approvePermissionThunk(params));
        } else {
            dispatch(rejectPermissionThunk(params));
        }
    };

    // 处理行点击，显示滑动面板
    const handleRowClick = (request) => {
        setSelectedRequest(request);
        setShowSlideOver(true);
    };

    // 关闭滑动面板
    const handleCloseSlideOver = () => {
        setShowSlideOver(false);
        setTimeout(() => {
            setSelectedRequest(null);
        }, 300); // 等待动画结束后再清除选中的申请
    };

    // 直接处理申请（不显示弹窗）
    const handleDirectProcess = (requestId, approve) => {
        setCurrentRequestId(requestId);
        setIsApproving(approve);

        const params = {
            id: requestId,
            responseMessage: approve ? '已批准' : '已拒绝',
        };

        if (approve) {
            dispatch(approvePermissionThunk(params));
        } else {
            dispatch(rejectPermissionThunk(params));
        }
    };

    // 获取当前页的数据
    const getCurrentPageData = () => {
        const startIndex = (currentPage - 1) * PAGE_SIZE;
        const endIndex = startIndex + PAGE_SIZE;
        return pendingRequests.slice(startIndex, endIndex);
    };

    // 处理页码变化
    const handlePageChange = (page) => {
        setCurrentPage(page);
    };

    // 渲染分页控件
    const renderPagination = () => {
        if (totalPages <= 1) return null;

        return (
            <div className='pagination-container'>
                <button
                    className='pagination-button'
                    onClick={() => handlePageChange(currentPage - 1)}
                    disabled={currentPage === 1}
                >
                    上一页
                </button>

                <div className='pagination-info'>
                    {currentPage} / {totalPages}
                </div>

                <button
                    className='pagination-button'
                    onClick={() => handlePageChange(currentPage + 1)}
                    disabled={currentPage === totalPages}
                >
                    下一页
                </button>
            </div>
        );
    };

    // 渲染加载状态
    if (fetchStatus === 'loading' && pendingRequests.length === 0) {
        return (
            <div className='text-center py-5'>
                <div className='spinner-border' role='status'>
                    <span className='visually-hidden'>加载中...</span>
                </div>
                <p className='mt-3'>加载待处理申请...</p>
            </div>
        );
    }

    // 渲染错误状态
    if (fetchStatus === 'failed' && pendingRequests.length === 0) {
        return (
            <div className='alert alert-danger' role='alert'>
                {fetchError || '获取待处理申请失败'}
            </div>
        );
    }

    // 渲染空状态
    if (pendingRequests.length === 0) {
        return (
            <div className='alert alert-info' role='alert'>
                暂无待处理的权限申请
            </div>
        );
    }

    // 获取当前页的数据
    const currentPageData = getCurrentPageData();

    // 渲染申请列表
    return (
        <>
            <div className='d-flex justify-content-between align-items-center mb-3'>
                <h5 className='mb-0'>待处理申请</h5>
                <div className='badge bg-danger'>{pendingRequests.length}个待处理</div>
            </div>

            <div className='pending-requests-list'>
                {currentPageData.map((request) => (
                    <div key={request.id} className='pending-request-item' onClick={() => handleRowClick(request)}>
                        <div className='request-header'>
                            <div className='user-info'>
                                <h6 className='mb-0'>{request.applicant.name}</h6>
                                <p className='department'>{request.applicant.department}</p>
                            </div>
                            <div className='request-date'>{new Date(request.created_at).toLocaleDateString()}</div>
                        </div>

                        <div className='request-content'>
                            <p className='mb-2'>申请访问：{request.knowledge_base.name}</p>

                            {request.permissions.can_edit ? (
                                <span
                                    className='badge bg-success-subtle text-success d-flex align-items-center gap-1'
                                    style={{ width: 'fit-content' }}
                                >
                                    <SvgIcon className={'circle-yes'} />
                                    完全访问
                                </span>
                            ) : (
                                request.permissions.can_read && (
                                    <span
                                        className='badge bg-warning-subtle text-warning d-flex align-items-center gap-1'
                                        style={{ width: 'fit-content' }}
                                    >
                                        <SvgIcon className={'eye'} />
                                        只读访问
                                    </span>
                                )
                            )}
                        </div>
                        <div className='request-actions'>
                            <button
                                className='btn btn-outline-danger'
                                onClick={(e) => {
                                    e.stopPropagation();
                                    handleDirectProcess(request.id, false);
                                }}
                                disabled={processingId === request.id && approveRejectStatus === 'loading'}
                            >
                                {processingId === request.id && approveRejectStatus === 'loading' && !isApproving
                                    ? '处理中...'
                                    : '拒绝'}
                            </button>
                            <button
                                className='btn btn-success'
                                onClick={(e) => {
                                    e.stopPropagation();
                                    handleDirectProcess(request.id, true);
                                }}
                                disabled={processingId === request.id && approveRejectStatus === 'loading'}
                            >
                                {processingId === request.id && approveRejectStatus === 'loading' && isApproving
                                    ? '处理中...'
                                    : '批准'}
                            </button>
                        </div>
                    </div>
                ))}
            </div>

            {/* 分页控件 */}
            {renderPagination()}

            {/* 滑动面板 */}
            <div className={`slide-over-backdrop ${showSlideOver ? 'show' : ''}`} onClick={handleCloseSlideOver}></div>
            <div className={`slide-over ${showSlideOver ? 'show' : ''}`}>
                {selectedRequest && (
                    <div className='slide-over-content'>
                        <div className='slide-over-header'>
                            <h5 className='mb-0'>申请详情</h5>
                            <button type='button' className='btn-close' onClick={handleCloseSlideOver}></button>
                        </div>
                        <div className='slide-over-body'>
                            <div className='mb-4'>
                                <h6 className='text-muted mb-2'>申请人信息</h6>
                                <div className='d-flex align-items-center mb-3'>
                                    <div className='avatar-placeholder me-3 bg-dark'>
                                        {(selectedRequest.applicant.name || selectedRequest.applicant).charAt(0)}
                                    </div>
                                    <div>
                                        <h5 className='mb-1'>
                                            {selectedRequest.applicant.name || selectedRequest.applicant}
                                        </h5>
                                        <p className='text-muted mb-0'>
                                            {selectedRequest.applicant.department || '无归属部门'}
                                        </p>
                                    </div>
                                </div>
                            </div>

                            <div className='mb-4'>
                                <h6 className='text-muted mb-2'>知识库信息</h6>
                                <p className='mb-1'>
                                    <strong>名称：</strong>{' '}
                                    {selectedRequest.knowledge_base.name || selectedRequest.knowledge_base}
                                </p>
                            </div>

                            <div className='mb-4'>
                                <h6 className='text-muted mb-2'>申请权限</h6>
                                <div className='d-flex flex-wrap gap-2 mb-3'>
                                    {selectedRequest.permissions.can_read && !selectedRequest.permissions.can_edit && (
                                        <span className='badge bg-warning-subtle text-warning d-flex align-items-center gap-1'>
                                            只读
                                        </span>
                                    )}
                                    {selectedRequest.permissions.can_edit && selectedRequest.permissions.can_delete && (
                                        <span className='badge bg-success-subtle text-success d-flex align-items-center gap-1'>
                                            完全访问
                                        </span>
                                    )}
                                </div>
                            </div>

                            <div className='mb-4'>
                                <h6 className='text-muted mb-2'>申请时间</h6>
                                <p className='mb-1'>{new Date(selectedRequest.created_at).toLocaleString()}</p>
                            </div>

                            {selectedRequest.expires_at && (
                                <div className='mb-4'>
                                    <h6 className='text-muted mb-2'>到期时间</h6>
                                    <p className='mb-1'>{new Date(selectedRequest.expires_at).toLocaleString()}</p>
                                </div>
                            )}

                            <div className='mb-4'>
                                <h6 className='text-muted mb-2'>申请理由</h6>
                                <div className='p-3 bg-light rounded'>{selectedRequest.reason || '无申请理由'}</div>
                            </div>
                        </div>
                        <div className='slide-over-footer'>
                            <button
                                className='btn btn-outline-danger me-2'
                                onClick={() => handleOpenResponseInput(selectedRequest.id, false)}
                                disabled={processingId === selectedRequest.id && approveRejectStatus === 'loading'}
                            >
                                {processingId === selectedRequest.id &&
                                approveRejectStatus === 'loading' &&
                                !isApproving ? (
                                    <>
                                        <span
                                            className='spinner-border spinner-border-sm me-1'
                                            role='status'
                                            aria-hidden='true'
                                        ></span>
                                        处理中...
                                    </>
                                ) : (
                                    <>拒绝</>
                                )}
                            </button>
                            <button
                                className='btn btn-success'
                                onClick={() => handleOpenResponseInput(selectedRequest.id, true)}
                                disabled={processingId === selectedRequest.id && approveRejectStatus === 'loading'}
                            >
                                {processingId === selectedRequest.id &&
                                approveRejectStatus === 'loading' &&
                                isApproving ? (
                                    <>
                                        <span
                                            className='spinner-border spinner-border-sm me-1'
                                            role='status'
                                            aria-hidden='true'
                                        ></span>
                                        处理中...
                                    </>
                                ) : (
                                    <>批准</>
                                )}
                            </button>
                        </div>
                    </div>
                )}
            </div>

            {/* 回复输入弹窗 */}
            {showResponseInput && (
                <div className='modal fade show' style={{ display: 'block' }} tabIndex='-1'>
                    <div className='modal-dialog'>
                        <div className='modal-content'>
                            <div className='modal-header'>
                                <h5 className='modal-title'>{isApproving ? '批准' : '拒绝'}申请</h5>
                                <button
                                    type='button'
                                    className='btn-close'
                                    onClick={handleCloseResponseInput}
                                    disabled={approveRejectStatus === 'loading'}
                                ></button>
                            </div>
                            <div className='modal-body'>
                                <div className='mb-3'>
                                    <label htmlFor='responseMessage' className='form-label'>
                                        审批意见
                                    </label>
                                    <textarea
                                        className='form-control'
                                        id='responseMessage'
                                        rows='3'
                                        value={responseMessage}
                                        onChange={(e) => setResponseMessage(e.target.value)}
                                        placeholder={isApproving ? '请输入批准意见（可选）' : '请输入拒绝理由（可选）'}
                                    ></textarea>
                                </div>
                            </div>
                            <div className='modal-footer'>
                                <button
                                    type='button'
                                    className='btn btn-secondary'
                                    onClick={handleCloseResponseInput}
                                    disabled={approveRejectStatus === 'loading'}
                                >
                                    取消
                                </button>
                                <button
                                    type='button'
                                    className={`btn ${isApproving ? 'btn-success' : 'btn-danger'}`}
                                    onClick={handleProcessRequest}
                                    disabled={approveRejectStatus === 'loading'}
                                >
                                    {approveRejectStatus === 'loading' ? (
                                        <>
                                            <span
                                                className='spinner-border spinner-border-sm me-1'
                                                role='status'
                                                aria-hidden='true'
                                            ></span>
                                            处理中...
                                        </>
                                    ) : isApproving ? (
                                        '确认批准'
                                    ) : (
                                        '确认拒绝'
                                    )}
                                </button>
                            </div>
                        </div>
                    </div>
                    <div className='modal-backdrop fade show'></div>
                </div>
            )}
        </>
    );
}
