import { createAsyncThunk } from '@reduxjs/toolkit';
import { get, post, put, del } from '../../services/api';

/**
 * 获取聊天列表
 * @param {Object} params - 查询参数
 * @param {number} params.page - 页码
 * @param {number} params.page_size - 每页数量
 */
export const fetchChats = createAsyncThunk(
    'chat/fetchChats',
    async (params = { page: 1, page_size: 10 }, { rejectWithValue }) => {
        try {
            const response = await get('/chat-history/', { params });

            // 处理返回格式
            if (response && response.code === 200) {
                return response.data;
            }

            return response.data || { results: [], total: 0, page: 1, page_size: 10 };
        } catch (error) {
            return rejectWithValue(error.response?.data || 'Failed to fetch chats');
        }
    }
);

/**
 * 创建新聊天
 * @param {Object} chatData - 聊天数据
 * @param {string} chatData.knowledge_base_id - 知识库ID
 * @param {string} chatData.title - 聊天标题
 */
export const createChat = createAsyncThunk('chat/createChat', async (chatData, { rejectWithValue }) => {
    try {
        const response = await post('/chat-history/', chatData);

        // 处理返回格式
        if (response && response.code === 200) {
            return response.data.chat;
        }

        return response.data?.chat || {};
    } catch (error) {
        return rejectWithValue(error.response?.data || 'Failed to create chat');
    }
});

/**
 * 更新聊天
 * @param {Object} params - 更新参数
 * @param {string} params.id - 聊天ID
 * @param {Object} params.data - 更新数据
 */
export const updateChat = createAsyncThunk('chat/updateChat', async ({ id, data }, { rejectWithValue }) => {
    try {
        const response = await put(`/chat-history/${id}/`, data);

        // 处理返回格式
        if (response && response.code === 200) {
            return response.data.chat;
        }

        return response.data?.chat || {};
    } catch (error) {
        return rejectWithValue(error.response?.data || 'Failed to update chat');
    }
});

/**
 * 删除聊天
 * @param {string} id - 聊天ID
 */
export const deleteChat = createAsyncThunk('chat/deleteChat', async (id, { rejectWithValue }) => {
    try {
        const response = await del(`/chat-history/${id}/`);

        // 处理返回格式
        if (response && response.code === 200) {
            return id;
        }

        return id;
    } catch (error) {
        return rejectWithValue(error.response?.data || 'Failed to delete chat');
    }
});
